@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2009 Cyrille Berger <cberger@cberger.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,8 +23,8 @@
 
 #include <KoIcon.h>
 
-#include "StateTool.h"
 #include "StateShape.h"
+#include "StateTool.h"
 
 StateToolFactory::StateToolFactory()
     : KoToolFactoryBase("StateToolFactoryID")
@@ -36,12 +36,9 @@ StateToolFactory::StateToolFactory()
     setActivationShapeId(STATESHAPEID);
 }
 
-StateToolFactory::~StateToolFactory()
-{
-}
+StateToolFactory::~StateToolFactory() = default;
 
-KoToolBase* StateToolFactory::createTool(KoCanvasBase * canvas)
+KoToolBase *StateToolFactory::createTool(KoCanvasBase *canvas)
 {
     return new StateTool(canvas);
 }
-
