@@ -1,22 +1,9 @@
 /*
  * This file is part of the KDE project
  *
- * Copyright (C) 2013 Arjen Hiemstra <ahiemstra@heimr.nl>
+ * SPDX-FileCopyrightText: 2013 Arjen Hiemstra <ahiemstra@heimr.nl>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
  */
 
@@ -25,8 +12,10 @@
 
 #include <QQuickItem>
 
-namespace Calligra {
-namespace Components {
+namespace Calligra
+{
+namespace Components
+{
 
 class View;
 
@@ -60,7 +49,7 @@ class ViewController : public QQuickItem
      * \set setView()
      * \notify viewChanged()
      */
-    Q_PROPERTY(Calligra::Components::View* view READ view WRITE setView NOTIFY viewChanged)
+    Q_PROPERTY(Calligra::Components::View *view READ view WRITE setView NOTIFY viewChanged)
     /**
      * \property flickable
      * \brief The flickable that is used to control scrolling.
@@ -70,7 +59,7 @@ class ViewController : public QQuickItem
      * \set setFlickable()
      * \notify flickableChanged()
      */
-    Q_PROPERTY(QQuickItem* flickable READ flickable WRITE setFlickable NOTIFY flickableChanged)
+    Q_PROPERTY(QQuickItem *flickable READ flickable WRITE setFlickable NOTIFY flickableChanged)
     /**
      * \property minimumZoom
      * \brief The minimum zoom level.
@@ -135,7 +124,7 @@ public:
      *
      * \param parent The parent item.
      */
-    explicit ViewController(QQuickItem* parent = 0);
+    explicit ViewController(QQuickItem *parent = nullptr);
     /**
      * Destructor.
      */
@@ -144,19 +133,19 @@ public:
     /**
      * Getter for property #view
      */
-    View* view() const;
+    View *view() const;
     /**
      * Setter for property #view
      */
-    void setView(View* newView);
+    void setView(View *newView);
     /**
      * Getter for property #flickable
      */
-    QQuickItem* flickable() const;
+    QQuickItem *flickable() const;
     /**
      * Setter for property #flickable
      */
-    void setFlickable(QQuickItem* item);
+    void setFlickable(QQuickItem *item);
     /**
      * Getter for property #minimumZoom
      */
@@ -201,7 +190,7 @@ public:
     /**
      * Reimlemented from superclass
      */
-    bool event(QEvent* event) override;
+    bool event(QEvent *event) override;
 public Q_SLOTS:
     /**
      * \brief Zoom by a specific amount around a centre point.
@@ -261,23 +250,23 @@ Q_SIGNALS:
     void useZoomProxyChanged();
 
 protected:
-    QSGNode* updatePaintNode(QSGNode* node, QQuickItem::UpdatePaintNodeData* ) override;
+    QSGNode *updatePaintNode(QSGNode *node, QQuickItem::UpdatePaintNodeData *) override;
 
 private Q_SLOTS:
     void documentChanged();
     void contentPositionChanged();
     void documentSizeChanged();
     void documentStatusChanged();
-    void documentOffsetChanged(const QPoint& offset);
+    void documentOffsetChanged(const QPoint &offset);
     void zoomTimeout();
     void flickableWidthChanged();
 
 private:
     class Private;
-    Private* const d;
+    Private *const d;
 };
 
 } // Namespace Components
-} // Namepsace Calligra
+} // Namespace Calligra
 
 #endif // CALLIGRA_COMPONENTS_VIEWCONTROLLER_H
