@@ -1,29 +1,21 @@
 /*
  * This file is part of Office 2007 Filters for Calligra
  *
- * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+ * SPDX-FileCopyrightText: 2010 Nokia Corporation and /or its subsidiary(-ies).
  *
  * Contact: Suresh Chande suresh.chande@nokia.com
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * version 2.1 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1-only
  *
  */
 
 #include "DocxXmlCommentsReader.h"
+
+#include "DocxDebug.h"
+
 #include <MsooXmlSchemas.h>
 #include <MsooXmlUtils.h>
+
 #include <KoXmlWriter.h>
 #include <limits.h>
 
@@ -36,10 +28,11 @@
 class DocxXmlCommentReader::Private
 {
 public:
-    Private() : counter(0) {
-    }
-    ~Private() {
+    Private()
+        : counter(0)
+    {
     }
+    ~Private() = default;
     QString pathAndFile;
     int counter;
 };
@@ -62,18 +55,18 @@ void DocxXmlCommentReader::init()
     d->counter = 0;
 }
 
-KoFilter::ConversionStatus DocxXmlCommentReader::read(MSOOXML::MsooXmlReaderContext* context)
+KoFilter::ConversionStatus DocxXmlCommentReader::read(MSOOXML::MsooXmlReaderContext *context)
 {
-    m_context = static_cast<DocxXmlDocumentReaderContext*>(context);
+    m_context = static_cast<DocxXmlDocumentReaderContext *>(context);
 
-    kDebug() << "=============================";
+    debugDocx << "=============================";
     readNext();
     if (!isStartDocument()) {
         return KoFilter::WrongFormat;
     }
     readNext();
 
-    kDebug() << *this << namespaceUri();
+    debugDocx << *this << namespaceUri();
     if (!expectEl(QList<QByteArray>() << "w:comments")) {
         return KoFilter::WrongFormat;
     }
@@ -97,7 +90,7 @@ KoFilter::ConversionStatus DocxXmlCommentReader::read(MSOOXML::MsooXmlReaderCont
     if (!expectElEnd(qn)) {
         return KoFilter::WrongFormat;
     }
-    kDebug() << "===========finished============";
+    debugDocx << "===========finished============";
 
     return KoFilter::OK;
 }
