@@ -1,49 +1,36 @@
 /* This file is part of the KDE project
-   Copyright (C) 2011 Thorsten Zachmann <zachmann@kde.org>
+   SPDX-FileCopyrightText: 2011 Thorsten Zachmann <zachmann@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "KoMarkerCollection.h"
 
 #include "KoMarker.h"
 #include "KoMarkerSharedLoadingData.h"
-#include <KoXmlReader.h>
-#include <KoShapeLoadingContext.h>
+#include <FlakeDebug.h>
 #include <KoOdfLoadingContext.h>
 #include <KoOdfReadStore.h>
+#include <KoShapeLoadingContext.h>
+#include <KoXmlReader.h>
 #include <QStandardPaths>
-#include <FlakeDebug.h>
+
+#include <QFile>
 
 class Q_DECL_HIDDEN KoMarkerCollection::Private
 {
 public:
-    ~Private()
-    {
-    }
+    ~Private() = default;
 
-    QList<QExplicitlySharedDataPointer<KoMarker> > markers;
+    QList<QExplicitlySharedDataPointer<KoMarker>> markers;
 };
 
 KoMarkerCollection::KoMarkerCollection(QObject *parent)
-: QObject(parent)
-, d(new Private)
+    : QObject(parent)
+    , d(new Private)
 {
     // Add no marker so the user can remove a marker from the line.
-    d->markers.append(QExplicitlySharedDataPointer<KoMarker>(0));
+    d->markers.append(QExplicitlySharedDataPointer<KoMarker>(nullptr));
     // Add default markers
     loadDefaultMarkers();
 }
@@ -56,12 +43,12 @@ KoMarkerCollection::~KoMarkerCollection()
 bool KoMarkerCollection::loadOdf(KoShapeLoadingContext &context)
 {
     debugFlake;
-    QHash<QString, KoMarker*> lookupTable;
+    QHash<QString, KoMarker *> lookupTable;
 
-    const QHash<QString, KoXmlElement*> markers = context.odfLoadingContext().stylesReader().drawStyles("marker");
+    const QHash<QString, KoXmlElement *> markers = context.odfLoadingContext().stylesReader().drawStyles("marker");
     loadOdfMarkers(markers, context, lookupTable);
 
-    KoMarkerSharedLoadingData * sharedMarkerData = new KoMarkerSharedLoadingData(lookupTable);
+    KoMarkerSharedLoadingData *sharedMarkerData = new KoMarkerSharedLoadingData(lookupTable);
     context.addSharedData(MARKER_SHARED_LOADING_ID, sharedMarkerData);
 
     return true;
@@ -72,8 +59,8 @@ void KoMarkerCollection::loadDefaultMarkers()
     // use the same mechanism for loading the markers that are available
     // per default as when loading the normal markers.
     KoOdfStylesReader markerReader;
-    KoOdfLoadingContext odfContext(markerReader, 0);
-    KoShapeLoadingContext shapeContext(odfContext, 0);
+    KoOdfLoadingContext odfContext(markerReader, nullptr);
+    KoShapeLoadingContext shapeContext(odfContext, nullptr);
     KoXmlDocument doc;
     QString filePath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "calligra/styles/markers.xml");
 
@@ -83,22 +70,20 @@ void KoMarkerCollection::loadDefaultMarkers()
         if (KoOdfReadStore::loadAndParse(&file, doc, errorMessage, filePath)) {
             markerReader.createStyleMap(doc, true);
 
-            QHash<QString, KoMarker*> lookupTable;
-            const QHash<QString, KoXmlElement*> defaultMarkers = markerReader.drawStyles("marker");
+            QHash<QString, KoMarker *> lookupTable;
+            const QHash<QString, KoXmlElement *> defaultMarkers = markerReader.drawStyles("marker");
             loadOdfMarkers(defaultMarkers, shapeContext, lookupTable);
-        }
-        else {
+        } else {
             warnFlake << "reading of" << filePath << "failed:" << errorMessage;
         }
-    }
-    else {
+    } else {
         debugFlake << "markers.xml not found";
     }
 }
 
-void KoMarkerCollection::loadOdfMarkers(const QHash<QString, KoXmlElement*> &markers, KoShapeLoadingContext &context, QHash<QString, KoMarker*> &lookupTable)
+void KoMarkerCollection::loadOdfMarkers(const QHash<QString, KoXmlElement *> &markers, KoShapeLoadingContext &context, QHash<QString, KoMarker *> &lookupTable)
 {
-    QHash<QString, KoXmlElement*>::const_iterator it(markers.constBegin());
+    QHash<QString, KoXmlElement *>::const_iterator it(markers.constBegin());
     for (; it != markers.constEnd(); ++it) {
         KoMarker *marker = new KoMarker();
         if (marker->loadOdf(*(it.value()), context)) {
@@ -108,26 +93,25 @@ void KoMarkerCollection::loadOdfMarkers(const QHash<QString, KoXmlElement*> &mar
             if (m != marker) {
                 delete marker;
             }
-        }
-        else {
+        } else {
             delete marker;
         }
     }
 }
 
-QList<KoMarker*> KoMarkerCollection::markers() const
+QList<KoMarker *> KoMarkerCollection::markers() const
 {
-    QMap<QString, KoMarker*> markerMap;
-    foreach (const QExplicitlySharedDataPointer<KoMarker>& m, d->markers) {
+    QMap<QString, KoMarker *> markerMap;
+    foreach (const QExplicitlySharedDataPointer<KoMarker> &m, d->markers) {
         const auto name = m ? m->name() : QString();
         markerMap[name] = m.data();
     }
     return markerMap.values();
 }
 
-KoMarker * KoMarkerCollection::addMarker(KoMarker *marker)
+KoMarker *KoMarkerCollection::addMarker(KoMarker *marker)
 {
-    foreach (const QExplicitlySharedDataPointer<KoMarker>& m, d->markers) {
+    foreach (const QExplicitlySharedDataPointer<KoMarker> &m, d->markers) {
         if (marker == m.data()) {
             return marker;
         }
