@@ -1,27 +1,15 @@
 /* This file is part of the KDE project
 
-   Copyright (C) 2010 Boudewijn Rempt
+   SPDX-FileCopyrightText: 2010 Boudewijn Rempt
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
  */
 #include "KoOdfNotesConfiguration.h"
 
-#include <OdfDebug.h>
+#include "KoOdfNumberDefinition.h"
 #include "KoXmlNS.h"
 #include "KoXmlWriter.h"
-#include "KoOdfNumberDefinition.h"
+#include <OdfDebug.h>
 
 class Q_DECL_HIDDEN KoOdfNotesConfiguration::Private
 {
@@ -40,7 +28,6 @@ public:
     KoOdfNotesConfiguration::FootnotesPosition footnotesPosition;
     QString footnotesContinuationForward;
     QString footnotesContinuationBackward;
-
 };
 
 KoOdfNotesConfiguration::KoOdfNotesConfiguration(NoteClass noteClass)
@@ -51,9 +38,9 @@ KoOdfNotesConfiguration::KoOdfNotesConfiguration(NoteClass noteClass)
     d->numberingScheme = BeginAtDocument;
     d->footnotesPosition = Page;
 
-    d->defaultNoteParagraphStyle = 0;
-    d->citationTextStyle = 0;
-    d->citationBodyTextStyle = 0;
+    d->defaultNoteParagraphStyle = nullptr;
+    d->citationTextStyle = nullptr;
+    d->citationBodyTextStyle = nullptr;
 
     if (noteClass == KoOdfNotesConfiguration::Footnote) {
         d->numberFormat.setFormatSpecification(KoOdfNumberDefinition::Numeric);
@@ -74,7 +61,8 @@ KoOdfNotesConfiguration::~KoOdfNotesConfiguration()
 }
 
 KoOdfNotesConfiguration::KoOdfNotesConfiguration(const KoOdfNotesConfiguration &other)
-    : QObject(), d(new Private())
+    : QObject()
+    , d(new Private())
 {
     d->noteClass = other.d->noteClass;
     d->citationTextStyleName = other.d->citationTextStyleName;
@@ -90,7 +78,6 @@ KoOdfNotesConfiguration::KoOdfNotesConfiguration(const KoOdfNotesConfiguration &
     d->footnotesPosition = other.d->footnotesPosition;
     d->footnotesContinuationForward = other.d->footnotesContinuationForward;
     d->footnotesContinuationBackward = other.d->footnotesContinuationBackward;
-
 }
 
 KoOdfNotesConfiguration &KoOdfNotesConfiguration::operator=(const KoOdfNotesConfiguration &other)
@@ -113,7 +100,6 @@ KoOdfNotesConfiguration &KoOdfNotesConfiguration::operator=(const KoOdfNotesConf
     return *this;
 }
 
-
 void KoOdfNotesConfiguration::loadOdf(const KoXmlElement &element)
 {
     d->citationTextStyleName = element.attributeNS(KoXmlNS::text, "citation-style-name", d->citationTextStyleName);
@@ -127,25 +113,20 @@ void KoOdfNotesConfiguration::loadOdf(const KoXmlElement &element)
     QString numberingScheme = element.attributeNS(KoXmlNS::text, "start-numbering-at", "document");
     if (numberingScheme == "document") {
         d->numberingScheme = BeginAtDocument;
-    }
-    else if (numberingScheme == "chapter") {
+    } else if (numberingScheme == "chapter") {
         d->numberingScheme = BeginAtChapter;
-    }
-    else if (numberingScheme == "page") {
+    } else if (numberingScheme == "page") {
         d->numberingScheme = BeginAtPage;
     }
 
-    QString footnotesPosition  = element.attributeNS(KoXmlNS::text, "footnotes-position", "page");
+    QString footnotesPosition = element.attributeNS(KoXmlNS::text, "footnotes-position", "page");
     if (footnotesPosition == "text") {
         d->footnotesPosition = Text;
-    }
-    else if (footnotesPosition == "page") {
+    } else if (footnotesPosition == "page") {
         d->footnotesPosition = Page;
-    }
-    else if (footnotesPosition == "section") {
+    } else if (footnotesPosition == "section") {
         d->footnotesPosition = Section;
-    }
-    else if (footnotesPosition == "document") {
+    } else if (footnotesPosition == "document") {
         d->footnotesPosition = Document;
     }
 
@@ -167,18 +148,27 @@ void KoOdfNotesConfiguration::saveOdf(KoXmlWriter *writer) const
 
     if (d->noteClass == Footnote) {
         writer->addAttribute("text:note-class", "footnote");
-    }
-    else if (d->noteClass == Endnote) {
+    } else if (d->noteClass == Endnote) {
         writer->addAttribute("text:note-class", "endnote");
     }
-    if (!d->citationTextStyleName.isNull()) {writer->addAttribute("text:citation-style-name", d->citationTextStyleName); }
-    if (!d->citationBodyTextStyleName.isNull()) {writer->addAttribute("text:citation-body-style-name", d->citationBodyTextStyleName); }
-    if (!d->defaultNoteParagraphStyleName.isNull()) {writer->addAttribute("text:default-style-name", d->defaultNoteParagraphStyleName); }
-    if (!d->masterPageName.isNull()) {writer->addAttribute("text:master-page-name", d->masterPageName); }
-    if (d->startValue != 0) { writer->addAttribute("text:start-value", d->startValue); }
+    if (!d->citationTextStyleName.isNull()) {
+        writer->addAttribute("text:citation-style-name", d->citationTextStyleName);
+    }
+    if (!d->citationBodyTextStyleName.isNull()) {
+        writer->addAttribute("text:citation-body-style-name", d->citationBodyTextStyleName);
+    }
+    if (!d->defaultNoteParagraphStyleName.isNull()) {
+        writer->addAttribute("text:default-style-name", d->defaultNoteParagraphStyleName);
+    }
+    if (!d->masterPageName.isNull()) {
+        writer->addAttribute("text:master-page-name", d->masterPageName);
+    }
+    if (d->startValue != 0) {
+        writer->addAttribute("text:start-value", d->startValue);
+    }
 
     d->numberFormat.saveOdf(writer);
-    switch(d->numberingScheme) {
+    switch (d->numberingScheme) {
     case BeginAtDocument:
         writer->addAttribute("text:start-numbering-at", "document");
         break;
@@ -189,7 +179,7 @@ void KoOdfNotesConfiguration::saveOdf(KoXmlWriter *writer) const
         writer->addAttribute("text:start-numbering-at", "page");
         break;
     }
-    switch(d->footnotesPosition) {
+    switch (d->footnotesPosition) {
     case Text:
         writer->addAttribute("text:footnotes-position", "text");
         break;
@@ -214,16 +204,14 @@ void KoOdfNotesConfiguration::saveOdf(KoXmlWriter *writer) const
         writer->endElement();
     }
 
-    writer->endElement(); //text:notes-configuration
+    writer->endElement(); // text:notes-configuration
 }
 
-
 KoOdfNotesConfiguration::NoteClass KoOdfNotesConfiguration::noteClass() const
 {
     return d->noteClass;
 }
 
-
 void *KoOdfNotesConfiguration::citationTextStyle() const
 {
     return d->citationTextStyle;
@@ -289,7 +277,6 @@ void KoOdfNotesConfiguration::setStartValue(int startValue)
     d->startValue = qMax(1, startValue);
 }
 
-
 KoOdfNumberDefinition KoOdfNotesConfiguration::numberFormat() const
 {
     return d->numberFormat;
